% Generate STFT using Matlab functions

clear
close all
clc


%% Generating a STFT

[x fs] = wavread('a075Leaf.wav');

% Narrowband
wlen = round(30*1e-3*fs);
olap = round(29*1e-3*fs);

% Wideband
% wlen = round(5*1e-3*fs);
% olap = round(4*1e-3*fs);

nfft    = 1024;                     % Number of discrete frequencies
maxf    = min(8000,fs/2);           % Maximum frequency to compute
f       = linspace(0, maxf, nfft);  % Values of frequencies to compute
[s,f,t] = spectrogram(x,wlen,olap,f,fs);

%% Plotting the STFT with axis labels
fplot = 1000; % Frequency tickmarks on spectrogram (in Hz)
tplot = 0.10;  % Time tickmarks on spectrogram (in seconds)

% Generate axis tickmarks
ftick = 0:fplot:max(f); % Frequency tickmark labels
ttick = 0:tplot:max(t); % Time tickmark labels
fix  = linspace(1,length(f),length(ftick));  % Index of frequencies
tix  = linspace(1,length(t),length(ttick));  % Index of time

imagesc(flipud(log(abs(s))));
set(gca,...
  'YTick', fix, ...
  'YTickLabel', fliplr(ftick),...
  'XTick', tix, ...
  'XTickLabel', ttick);
xlabel('Time (s)')
ylabel('Freq (Hz)')

%% Or you can have Matlab plot it directly as
spectrogram(x,wlen,olap,f,fs, 'yaxis');
